@@ -25,19 +25,8 @@ summary_SCA_Pope <- function(Assessment) {
   derived <- data.frame(Value = Value, Description = Description, stringsAsFactors = FALSE)
   rownames(derived) <- c("VB0", "SSB0", "MSY", "UMSY", "VBMSY", "SSBMSY", "SSBMSY/SSB0")
 
-  if(!is.character(SD)) {
-    model_estimates <- summary(SD)[rownames(summary(SD)) != "log_rec_dev" & rownames(summary(SD)) != "log_early_rec_dev", ]
-    model_estimates <- model_estimates[!is.na(model_estimates[, 2]) && model_estimates[, 2] > 0, ]
-
-    if(length(Dev) > 0) {
-      if(length(SE_Dev) == 0) SE_Dev <- rep(NA, length(Dev))
-      dev_estimates <- cbind(Dev, SE_Dev)
-      rownames(dev_estimates) <- paste0("log_rec_dev_", names(Dev))
-
-      model_estimates <- rbind(model_estimates, dev_estimates)
-    }
-  } else {
-    model_estimates <- SD
+  if(!is.character(model_estimates)) {
+    rownames(model_estimates)[rownames(model_estimates) == "log_rec_dev"] <- paste0("log_rec_dev_", names(FMort)[as.logical(obj$env$data$est_rec_dev)])
   }
 
   output <- list(model = "Statistical Catch-at-Age (SCA_Pope)",
